@@ -36,13 +36,39 @@ DAQ_trigger.CONTINUOUS
     
 """
 
+global cnt_DAQ_updated, cnt_send_updated, cnt_DAQ_paused
+
+
+@QtCore.pyqtSlot()
+def process_DAQ_updated():
+    # In production code, your GUI update routine would go here
+    tprint("---> received: DAQ_updated")
+    global cnt_DAQ_updated
+    cnt_DAQ_updated += 1
+
+
+@QtCore.pyqtSlot()
+def process_DAQ_paused():
+    # In production code, your GUI update routine would go here
+    tprint("---> received: DAQ_paused")
+    global cnt_DAQ_paused
+    cnt_DAQ_paused += 1
+
+
+@QtCore.pyqtSlot()
+def process_send_updated():
+    # In production code, your GUI update routine would go here
+    tprint("---> received: send_updated")
+    global cnt_send_updated
+    cnt_send_updated += 1
+
 
 class FakeDevice:
-    def __init__(self, name="FakeDev"):
+    def __init__(self, start_alive=True):
         # Required members
-        self.name = name
+        self.name = "FakeDev"
         self.mutex = QtCore.QMutex()
-        self.is_alive = True
+        self.is_alive = start_alive
 
         # Member for testing
         self.count_commands = 0
@@ -52,20 +78,24 @@ class FakeDevice:
         if self.is_alive:
             # Simulate successful device output
             self.count_replies += 1
-            tprint(data_to_be_send)
+            tprint_tab(data_to_be_send)
             return data_to_be_send
         else:
             # Simulate device failure
             time.sleep(0.1)
-            tprint("SIMULATED I/O ERROR")
+            tprint_tab("SIMULATED I/O ERROR")
             return "SIMULATED I/O ERROR"
 
-    def fake_query(self):
+    def fake_query_1(self):
         self.count_commands += 1
-        return self._send("device replied")
+        return self._send("-> reply 0101")
 
-    def fake_command_with_argument(self, val):
-        tprint("device received command")
+    def fake_query_2(self):
+        self.count_commands += 1
+        return self._send("-> reply ~~~~")
+
+    def fake_command_with_argument(self, val: int):
+        tprint_tab("-> command(arg=%i)" % val)
         self.count_commands += 1
 
 
@@ -75,6 +105,12 @@ def create_QApplication():
     # QtWidgets are not needed for pytest and will fail standard Travis test
     # app = QtWidgets.QApplication(sys.argv)
     app = QtCore.QCoreApplication(sys.argv)  # Use QCoreApplication instead
+
+    global cnt_DAQ_updated, cnt_DAQ_paused, cnt_send_updated
+    cnt_DAQ_updated = 0
+    cnt_DAQ_paused = 0
+    cnt_send_updated = 0
+
     return app
 
 
@@ -83,48 +119,38 @@ def print_title(title):
     dprint("-" * 50, ANSI.PURPLE)
 
 
+def tprint_tab(str_msg, ANSI_color=None):
+    dprint(" " * 60 + "%.4f %s" % (time.perf_counter(), str_msg), ANSI_color)
+
+
+# ------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
+
 def test_Worker_DAQ___INTERNAL_TIMER(start_alive=True):
     print_title(
         "Worker_DAQ - INTERNAL_TIMER" + ("" if start_alive else " - start dead")
     )
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-    dev.is_alive = start_alive
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
 
     def DAQ_function():
         # Must return True when successful, False otherwise
-        reply = dev.fake_query()
-        return reply[-14:] == "device replied"
-
-    global signal_counter
-    signal_counter = 0
-
-    @QtCore.pyqtSlot()
-    def process_DAQ_updated():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: DAQ_updated")
-        global signal_counter
-        signal_counter += 1
-
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
+        reply = dev.fake_query_1()
+        return reply[-4:] == "0101"
 
+    app = create_QApplication()
+    dev = FakeDevice(start_alive=start_alive)
+    qdevio = QDeviceIO(dev)
     # fmt: off
-    # Worker_DAQ in mode INTERNAL TIMER
     qdevio.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
         DAQ_function               = DAQ_function,
         DAQ_interval_ms            = 100,
-        DAQ_timer_type             = QtCore.Qt.CoarseTimer,
+        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
         critical_not_alive_count   = 10,
         calc_DAQ_rate_every_N_iter = 5,
         DEBUG                      = DEBUG)
     # fmt: on
-
+    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
     assert qdevio.start() == start_alive
 
     # Simulate device runtime
@@ -144,8 +170,8 @@ def test_Worker_DAQ___INTERNAL_TIMER(start_alive=True):
         assert dev.count_commands >= 3
         assert dev.count_replies >= 3
         assert (
-            signal_counter >= 2
-        )  # Third signal is not always received before thread is quit
+            cnt_DAQ_updated >= 2
+        )  # Last signal is not always received before thread is quit
 
 
 def test_Worker_DAQ___INTERNAL_TIMER__start_dead():
@@ -157,34 +183,16 @@ def test_Worker_DAQ___SINGLE_SHOT_WAKE_UP(start_alive=True):
         "Worker_DAQ - SINGLE_SHOT_WAKE_UP"
         + ("" if start_alive else " - start dead")
     )
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-    dev.is_alive = start_alive
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
 
     def DAQ_function():
         # Must return True when successful, False otherwise
-        reply = dev.fake_query()
-        return reply[-14:] == "device replied"
-
-    global signal_counter
-    signal_counter = 0
-
-    @QtCore.pyqtSlot()
-    def process_DAQ_updated():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: DAQ_updated")
-        global signal_counter
-        signal_counter += 1
-
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
+        reply = dev.fake_query_1()
+        return reply[-4:] == "0101"
 
+    app = create_QApplication()
+    dev = FakeDevice(start_alive=start_alive)
+    qdevio = QDeviceIO(dev)
     # fmt: off
-    # Worker_DAQ in mode SINGLE_SHOT_WAKE_UP
     qdevio.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.SINGLE_SHOT_WAKE_UP,
         DAQ_function               = DAQ_function,
@@ -192,7 +200,7 @@ def test_Worker_DAQ___SINGLE_SHOT_WAKE_UP(start_alive=True):
         calc_DAQ_rate_every_N_iter = 5,
         DEBUG                      = DEBUG)
     # fmt: on
-
+    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
     assert qdevio.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
@@ -214,7 +222,7 @@ def test_Worker_DAQ___SINGLE_SHOT_WAKE_UP(start_alive=True):
     if start_alive:
         assert dev.count_commands == 3
         assert dev.count_replies == 3
-        assert signal_counter == 3
+        assert cnt_DAQ_updated == 3
 
 
 def test_Worker_DAQ___SINGLE_SHOT_WAKE_UP__start_dead():
@@ -225,54 +233,27 @@ def test_Worker_DAQ___CONTINUOUS(start_alive=True):
     print_title(
         "Worker_DAQ - CONTINUOUS" + ("" if start_alive else " - start dead")
     )
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-    dev.is_alive = start_alive
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
 
     def DAQ_function():
         # Must return True when successful, False otherwise
         time.sleep(0.1)  # Simulate blocking processing time on the device
-        reply = dev.fake_query()
-        return reply[-14:] == "device replied"
-
-    global signal_counter_updated
-    signal_counter_updated = 0
-
-    @QtCore.pyqtSlot()
-    def process_DAQ_updated():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: DAQ_updated")
-        global signal_counter_updated
-        signal_counter_updated += 1
-
-    global signal_counter_paused
-    signal_counter_paused = 0
-
-    @QtCore.pyqtSlot()
-    def process_DAQ_paused():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: DAQ_paused")
-        global signal_counter_paused
-        signal_counter_paused += 1
-
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
-    qdevio.signal_DAQ_paused.connect(process_DAQ_paused)
+        reply = dev.fake_query_1()
+        return reply[-4:] == "0101"
 
+    app = create_QApplication()
+    dev = FakeDevice(start_alive=start_alive)
+    qdevio = QDeviceIO(dev)
     # fmt: off
-    # Worker_DAQ in mode CONTINUOUS
     qdevio.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.CONTINUOUS,
         DAQ_function               = DAQ_function,
         critical_not_alive_count   = 1,
         calc_DAQ_rate_every_N_iter = 5,
-        DEBUG                      = DEBUG)
+        DEBUG                      = DEBUG,
+    )
     # fmt: on
-
+    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
+    qdevio.signal_DAQ_paused.connect(process_DAQ_paused)
     assert qdevio.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
@@ -299,9 +280,9 @@ def test_Worker_DAQ___CONTINUOUS(start_alive=True):
         assert dev.count_commands >= 10
         assert dev.count_replies >= 10
         assert (
-            signal_counter_updated >= 9
+            cnt_DAQ_updated >= 9
         )  # Last signal is not always received before thread is quit
-        assert signal_counter_paused == 3
+        assert cnt_DAQ_paused == 3
 
 
 def test_Worker_DAQ___CONTINUOUS__start_dead():
@@ -310,39 +291,22 @@ def test_Worker_DAQ___CONTINUOUS__start_dead():
 
 def test_Worker_send(start_alive=True):
     print_title("Worker_send" + ("" if start_alive else " - start dead"))
+
     app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-    dev.is_alive = start_alive
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
-
-    global signal_counter
-    signal_counter = 0
-
-    @QtCore.pyqtSlot()
-    def process_send_updated():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: send_updated")
-        global signal_counter
-        signal_counter += 1
-
-    qdevio.signal_send_updated.connect(process_send_updated)
-
+    dev = FakeDevice(start_alive=start_alive)
+    qdevio = QDeviceIO(dev)
     qdevio.create_worker_send(DEBUG=DEBUG)
-
+    qdevio.signal_send_updated.connect(process_send_updated)
     assert qdevio.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.add_to_send_queue(dev.fake_query)
+    qdevio.add_to_send_queue(dev.fake_query_2)
 
     # fmt: off
     # Simulate device runtime
     start_time = time.perf_counter()
     QtCore.QTimer.singleShot(100, lambda: qdevio.process_send_queue())
-    QtCore.QTimer.singleShot(200, lambda: qdevio.send(dev.fake_query))
+    QtCore.QTimer.singleShot(200, lambda: qdevio.send(dev.fake_query_2))
     QtCore.QTimer.singleShot(300, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
     QtCore.QTimer.singleShot(400, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
     QtCore.QTimer.singleShot(500, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
@@ -361,7 +325,7 @@ def test_Worker_send(start_alive=True):
     if start_alive:
         assert dev.count_commands == 5
         assert dev.count_replies == 2
-        assert signal_counter == 4
+        assert cnt_send_updated == 4
 
 
 def test_Worker_send__start_dead():
@@ -370,43 +334,27 @@ def test_Worker_send__start_dead():
 
 def test_Worker_send__jobs_function():
     print_title("Worker_send - jobs_function")
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
-
-    global signal_counter
-    signal_counter = 0
-
-    @QtCore.pyqtSlot()
-    def process_send_updated():
-        # In production code, your GUI update routine would go here
-        tprint("---> Received signal: send_updated")
-        global signal_counter
-        signal_counter += 1
-
-    qdevio.signal_send_updated.connect(process_send_updated)
 
     def jobs_function(func, args):
         if func == "special command":
-            dev.fake_query()
+            dev.fake_query_2()
         else:
             # Default job handling where, e.g.
             # func = self.dev.write
             # args = ("toggle LED",)
             func(*args)
 
+    app = create_QApplication()
+    dev = FakeDevice()
+    qdevio = QDeviceIO(dev)
     qdevio.create_worker_send(
         jobs_function=jobs_function, DEBUG=DEBUG,
     )
-
+    qdevio.signal_send_updated.connect(process_send_updated)
     assert qdevio.start() == True
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.send(dev.fake_query)
+    qdevio.send(dev.fake_query_2)
 
     # fmt: off
     # Simulate device runtime
@@ -425,19 +373,17 @@ def test_Worker_send__jobs_function():
 
     assert dev.count_commands == 3
     assert dev.count_replies == 2
-    assert signal_counter == 3
+    assert cnt_send_updated == 3
 
 
 def test_attach_device_twice():
     print_title("Attach device twice")
     import pytest
 
-    dev = FakeDevice()
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
+    qdevio = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.attach_device(dev)
+        qdevio.attach_device(FakeDevice())
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 22
@@ -473,9 +419,7 @@ def test_Worker_DAQ___start_without_create():
     print_title("Worker_DAQ - start without create")
     import pytest
 
-    dev = FakeDevice()
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
+    qdevio = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
         qdevio.start_worker_DAQ()
@@ -488,9 +432,7 @@ def test_Worker_send__start_without_create():
     print_title("Worker_send - start without create")
     import pytest
 
-    dev = FakeDevice()
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
+    qdevio = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
         qdevio.start_worker_send()
@@ -501,14 +443,9 @@ def test_Worker_send__start_without_create():
 
 def test_Worker_DAQ___quit_without_start():
     print_title("Worker_DAQ - quit without start")
+
     app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
-
+    qdevio = QDeviceIO(FakeDevice())
     qdevio.create_worker_DAQ()
 
     tprint("About to quit")
@@ -519,14 +456,9 @@ def test_Worker_DAQ___quit_without_start():
 
 def test_Worker_send__quit_without_start():
     print_title("Worker_send - quit without start")
+
     app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
-
+    qdevio = QDeviceIO(FakeDevice())
     qdevio.create_worker_send()
 
     tprint("About to quit")
@@ -537,37 +469,31 @@ def test_Worker_send__quit_without_start():
 
 def test_Worker_DAQ___rate():
     print_title("Worker_DAQ - INTERNAL_TIMER - DAQ rate")
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
 
     def DAQ_function():
-        dprint(qdevio.obtained_DAQ_interval_ms)
-        dprint(qdevio.obtained_DAQ_rate_Hz)
-        return True
+        # Must return True when successful, False otherwise
+        reply = dev.fake_query_1()
+        dprint(" " * 50 + "%.1f Hz" % qdevio.obtained_DAQ_rate_Hz)
+        return reply[-4:] == "0101"
 
+    app = create_QApplication()
+    dev = FakeDevice()
+    qdevio = QDeviceIO(dev)
     # fmt: off
-    # Worker_DAQ in mode INTERNAL TIMER
     qdevio.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
         DAQ_function               = DAQ_function,
-        DAQ_interval_ms            = 20,
+        DAQ_interval_ms            = 10,
         DAQ_timer_type             = QtCore.Qt.PreciseTimer,
         critical_not_alive_count   = 1,
-        calc_DAQ_rate_every_N_iter = 25,
+        calc_DAQ_rate_every_N_iter = 20,
         DEBUG                      = DEBUG)
     # fmt: on
-
-    print(qdevio.worker_DAQ.calc_DAQ_rate_every_N_iter)
     assert qdevio.start() == True
 
     # Simulate device runtime
     start_time = time.perf_counter()
-    while time.perf_counter() - start_time < 1.02:
+    while time.perf_counter() - start_time < 0.51:
         app.processEvents()
         time.sleep(0.001)  # Do not hog the CPU
 
@@ -577,42 +503,24 @@ def test_Worker_DAQ___rate():
     app.quit()
 
     assert (
-        qdevio.obtained_DAQ_interval_ms
-        >= 19 & qdevio.obtained_DAQ_interval_ms
-        <= 21
+        qdevio.obtained_DAQ_interval_ms >= 9
+        and qdevio.obtained_DAQ_interval_ms <= 11
+    )
+    assert (
+        qdevio.obtained_DAQ_rate_Hz >= 99 and qdevio.obtained_DAQ_rate_Hz <= 101
     )
-    assert round(qdevio.obtained_DAQ_rate_Hz) == 50
 
 
 def test_Worker_DAQ___lose_connection():
     print_title("Worker_DAQ - INTERNAL_TIMER - lose connection")
-    app = create_QApplication()
-
-    # Simulate a device
-    dev = FakeDevice()
-
-    qdevio = QDeviceIO()
-    assert qdevio.attach_device(dev) == True
 
     def DAQ_function():
-        if qdevio.update_counter_DAQ == 30:
+        # Must return True when successful, False otherwise
+        if qdevio.update_counter_DAQ == 10:
             dev.is_alive = False
-        reply = dev.fake_query()
-        dprint(qdevio.obtained_DAQ_interval_ms)
-        dprint(qdevio.obtained_DAQ_rate_Hz)
-        return reply[-14:] == "device replied"
 
-    # fmt: off
-    # Worker_DAQ in mode INTERNAL TIMER
-    qdevio.create_worker_DAQ(
-        DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
-        DAQ_function               = DAQ_function,
-        DAQ_interval_ms            = 20,
-        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
-        critical_not_alive_count   = 3,
-        calc_DAQ_rate_every_N_iter = 20,
-        DEBUG                      = DEBUG)
-    # fmt: on
+        reply = dev.fake_query_1()
+        return reply[-4:] == "0101"
 
     # NOTE: The global 'go' mechanism used here is a quick and dirty way to
     # pytest. In production, it should be implemented by an boolean external
@@ -622,12 +530,24 @@ def test_Worker_DAQ___lose_connection():
 
     @QtCore.pyqtSlot()
     def process_connection_lost():
-        tprint("---> Received signal: connection_lost")
+        tprint("---> received: connection_lost")
         global go
         go = False
 
+    app = create_QApplication()
+    dev = FakeDevice()
+    qdevio = QDeviceIO(dev)
+    # fmt: off
+    qdevio.create_worker_DAQ(
+        DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
+        DAQ_function               = DAQ_function,
+        DAQ_interval_ms            = 20,
+        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
+        critical_not_alive_count   = 3,
+        calc_DAQ_rate_every_N_iter = 20,
+        DEBUG                      = DEBUG)
+    # fmt: on
     qdevio.signal_connection_lost.connect(process_connection_lost)
-
     assert qdevio.start() == True
 
     # Simulate device runtime
@@ -641,6 +561,72 @@ def test_Worker_DAQ___lose_connection():
     app.quit()
 
 
+class QDeviceIO_subclassed(QDeviceIO, QtCore.QObject):
+    def __init__(
+        self, dev=None, DAQ_function=None, DEBUG=False, parent=None,
+    ):
+        super(QDeviceIO_subclassed, self).__init__(parent=parent)
+
+        assert self.attach_device(dev) == True
+
+        # fmt: off
+        self.create_worker_DAQ(
+            DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
+            DAQ_function               = DAQ_function,
+            DAQ_interval_ms            = 100,
+            DAQ_timer_type             = QtCore.Qt.PreciseTimer,
+            critical_not_alive_count   = 10,
+            calc_DAQ_rate_every_N_iter = 5,
+            DEBUG                      = DEBUG,
+        )
+        # fmt: on
+        self.create_worker_send(DEBUG=DEBUG)
+
+
+def test_Worker_DAQ___INTERNAL_TIMER__mixin_class():
+    print_title("Worker_DAQ - INTERNAL_TIMER - mixin class")
+
+    def DAQ_function():
+        # Must return True when successful, False otherwise
+        reply = dev.fake_query_1()
+        return reply[-4:] == "0101"
+
+    app = create_QApplication()
+    dev = FakeDevice()
+    qdevio = QDeviceIO_subclassed(
+        dev=dev, DAQ_function=DAQ_function, DEBUG=DEBUG,
+    )
+    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
+    qdevio.signal_send_updated.connect(process_send_updated)
+    qdevio.start()
+
+    # fmt: off
+    # Simulate device runtime
+    start_time = time.perf_counter()
+    QtCore.QTimer.singleShot(300, lambda: qdevio.send(dev.fake_query_2))
+    QtCore.QTimer.singleShot(600, lambda: qdevio.send(dev.fake_command_with_argument, 0))
+    # fmt: on
+    while time.perf_counter() - start_time < 1:
+        app.processEvents()
+        time.sleep(0.001)  # Do not hog the CPU
+
+    tprint("About to quit")
+    app.processEvents()
+    assert qdevio.quit() == True
+    app.quit()
+
+    assert dev.count_commands >= 11
+    assert dev.count_replies >= 10
+    assert (
+        cnt_DAQ_updated >= 9
+    )  # Last signal is not always received before thread is quit
+    assert cnt_send_updated == 2
+
+
+# ------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
+
 if __name__ == "__main__":
     ALL = True
     if ALL:
@@ -662,6 +648,7 @@ if __name__ == "__main__":
         test_Worker_send__quit_without_start()
         test_Worker_DAQ___rate()
         test_Worker_DAQ___lose_connection()
+        test_Worker_DAQ___INTERNAL_TIMER__mixin_class()
     else:
         # test_Worker_DAQ___INTERNAL_TIMER()
         # test_Worker_DAQ___INTERNAL_TIMER__start_dead()
@@ -676,10 +663,10 @@ if __name__ == "__main__":
                 break
         """
 
-        test_Worker_DAQ___CONTINUOUS()
+        # test_Worker_DAQ___CONTINUOUS()
         # test_Worker_DAQ___CONTINUOUS__start_dead()
 
-        # test_Worker_DAQ___rate()
+        test_Worker_DAQ___rate()
         # test_Worker_DAQ___lose_connection()
         # test_Worker_DAQ___no_device_attached()
         # test_Worker_DAQ___start_without_create()
@@ -694,3 +681,5 @@ if __name__ == "__main__":
         # test_Worker_send__quit_without_start()
 
         # test_attach_device_twice()
+
+        # test_Worker_DAQ___INTERNAL_TIMER__mixin_class()
